/******************************************************************************
 * (c) Copyright 2002-2006, 1060 Research Ltd
 *
 * This Software is licensed to You, the licensee, for use under the terms of
 * the 1060 Public License v1.0. Please read and agree to the 1060 Public
 * License v1.0 [www.1060research.com/license] before using or redistributing
 * this software.
 *
 * In summary the 1060 Public license has the following conditions.
 * A. You may use the Software free of charge provided you agree to the terms
 * laid out in the 1060 Public License v1.0
 * B. You are only permitted to use the Software with components or applications
 * that provide you with OSI Certified Open Source Code [www.opensource.org], or
 * for which licensing has been approved by 1060 Research Limited.
 * You may write your own software for execution by this Software provided any
 * distribution of your software with this Software complies with terms set out
 * in section 2 of the 1060 Public License v1.0
 * C. You may redistribute the Software provided you comply with the terms of
 * the 1060 Public License v1.0 and that no warranty is implied or given.
 * D. If you find you are unable to comply with this license you may seek to
 * obtain an alternative license from 1060 Research Limited by contacting
 * license@1060research.com or by visiting www.1060research.com
 *
 * NO WARRANTY:  THIS SOFTWARE IS NOT COVERED BY ANY WARRANTY. SEE 1060 PUBLIC
 * LICENSE V1.0 FOR DETAILS
 *
 * THIS COPYRIGHT NOTICE IS *NOT* THE 1060 PUBLIC LICENSE v1.0. PLEASE READ
 * THE DISTRIBUTED 1060_Public_License.txt OR www.1060research.com/license
 *
 * File:          $RCSfile$
 * Version:       $Name$ $Revision$
 * Last Modified: $Date$
 *****************************************************************************/
package org.netkernel.layer0.nkf;

import org.netkernel.request.IRequestResponseFields;

/**
 * The response to be issued as the result of the invocation of an accessor
 * @author  tab
 */
@SuppressWarnings("unchecked")
public interface INKFResponse extends INKFResponseReadOnly
{
	static final int EXPIRY_ALWAYS=0;
	static final int EXPIRY_CONSTANT=1;
	static final int EXPIRY_NEVER=2;
	static final int EXPIRY_DEPENDENT=3;
	static final int EXPIRY_MIN_CONSTANT_DEPENDENT=4;
	static final int EXPIRY_MAX_CONSTANT_DEPENDENT=5;
	static final int EXPIRY_FUNCTION=6;
	static final int EXPIRY_MIN_FUNCTION_DEPENDENT=7;
	static final int EXPIRY_POLLED_DEPENDENT=8;
	
	/** Set the mode of expiry for this response
	 * @param aType one of the EXPIRY_ constants
	 */
	void setExpiry(int aType);
	
	/** Set the mode of expiry for this response
	 * @param aType one of the EXPIRY_ constants
	 * @param aConstant an absolute time value (use System.currentTimeMillis() as an offset if you want relative)
	 */
	void setExpiry(int aType, long aConstant);
	
	/** Set the mode of expiry for this response
	 * @param aType one of the EXPIRY_ constants
	 * @param aFunction a user defined expiry function
	 */
	void setExpiry(int aType, INKFExpiryFunction aFunction);
	
	/** Sets a specific user defined header on the response, this will replace any existing value(s)
	 * @param aName the name of the header
	 * @param aRepresentation the value of this header
	 */
	void setHeader(String aName, Object aRepresentation);
	
	 /** Sets all user defined headers on response replacing any existing headers
	 * @param aHeaders
	 */
	void setHeaders(IRequestResponseFields aHeaders);

	/** Sets the mimetype of this response. By default the mimetype
	 * will be undefined. Mimetype is equivalent to metadata with a key
	 * of "mimetype"
	 * @param aType
	 */
	void setMimeType(String aType);
	
	/** Marks this response to not be cached. This doesn't effect the expiry of
	 * the response so dependencies may still be cached.
	 */
	void setNoCache();
	
	/** Boost the cacheability of response above it's default. This
	 * should be used as a tuning mechanism to aid the retention
	 * of key resource representations.
	 * @param aBoost an integer>0, <0 will be clipped to 0. The default
	 * boost if this method is not called is 0.
	 */
	void setCacheBoost(int aBoost);
}